# qenerate: plugin=pydantic_v2

query CourseIndex {
    allCourses {
        _id
        name
        courseNickname

        term {
            id
            startAt
            endAt
            name
        }
    }
}